[crash] rename crash report generation timeout

* the timeout is already also used for Feedback device ID collection and
  soon for update channel collection

Change-Id: I0a059799b09a68394d1afdd266c48bf43836f9f8
Reviewed-on: https://fuchsia-review.googlesource.com/c/fuchsia/+/378006
Testability-Review: Francois Rousseau <frousseau@google.com>
Reviewed-by: Daniel Salazar Villarreal <villarreald@google.com>
Commit-Queue: Francois Rousseau <frousseau@google.com>
diff --git a/src/developer/feedback/crashpad_agent/crash_reporter.cc b/src/developer/feedback/crashpad_agent/crash_reporter.cc
index 6a54b6c..b42a71a 100644
--- a/src/developer/feedback/crashpad_agent/crash_reporter.cc
+++ b/src/developer/feedback/crashpad_agent/crash_reporter.cc
@@ -31,11 +31,13 @@
 using fuchsia::feedback::CrashReport;
 using fuchsia::feedback::Data;
 
-// This should be kept higher than the timeout the component serving fuchsia.feedback.DataProvider
-// has on its side for each feedback data as we pay the price for making the request (establishing
-// the connection, potentially spawning the serving component for the first time, getting the
-// response, etc.) .
-constexpr zx::duration kFeedbackDataCollectionTimeout = zx::sec(30) + /*some slack*/ zx::sec(5);
+// Most of the time spent generating a crash report is spent collecting annotations and attachments
+// from other services. The timeout should be kept higher than how long any of these services might
+// take as we pay the extra price on top of that timeout for making the request (establishing the
+// connection, potentially spawning the serving component for the first time, getting the response,
+// etc.).
+constexpr zx::duration kCrashReportGenerationTimeout =
+    zx::sec(30) /*fuchsia.feedback.DataProvider*/ + zx::sec(5) /*some slack*/;
 
 }  // namespace
 
@@ -125,8 +127,8 @@
   }
   FX_LOGS(INFO) << "Generating crash report for " << report.program_name();
 
-  auto data_promise = data_provider_.GetData(kFeedbackDataCollectionTimeout);
-  auto device_id_promise = device_id_provider_.GetId(kFeedbackDataCollectionTimeout);
+  auto data_promise = data_provider_.GetData(kCrashReportGenerationTimeout);
+  auto device_id_promise = device_id_provider_.GetId(kCrashReportGenerationTimeout);
 
   auto promise = fit::join_promises(std::move(data_promise), std::move(device_id_promise))
                      .then([this, report = std::move(report)](